Acer Stock Drops Following Gateway Bid | Groundhog Tech News
Description: Acer Inc.'s shares fell sharply Tuesday, one day after the Taiwanese computer maker said it would acquire Gateway Inc. for $710 million. Acer said it ...

# Acer Stock Drops Following Gateway Bid

## Acer Stock Drops Following Gateway Bid Acer Inc.’s shares fell sharply Tuesday, one day after the Taiwanese computer maker said it would acquire Gateway Inc. for $710 million. Acer said it will pay $1.90 a share, a 57 percent premium to the closing price of U.S.-based Gateway’s shares on Friday. The deal, expected to close by December, will push the combined company past China’s Lenovo Group Ltd. as the world’s third-largest vendor of personal computers, behind Hewlett-Packard Co. and Dell Inc. Some analysts believe the deal may be overpriced and Acer could be paying too much to expand market share. Acer shares dropped 6.9 percent Tuesday, nearly the daily downside limit of 7 percent at NT$59.20, where they had been for most of the session. “It’s a very expensive deal,” said Calvin Huang, an analyst at BNP Paribas, which maintained a “buy” rating on Acer’s shares. He estimates the acquisition’s fair value at a 10 percent to 20 percent premium to Gateway’s Friday closing price. “Acer is now paying around $350 million for every additional 1 percent of global market share,” Huang said. By comparison, when Lenovo Group Ltd. bought the personal computer arm of International Business Machines Corp. in 2005, it paid $290 million for every 1 percent of additional global market share, Huang said. There may be more selling pressure in coming days as investors wait for further details of the deal, especially the price of Gateway’s planned acquisition of the parent company of Packard Bell BV, a PC maker based in the Netherlands, analysts said. Macquarie Research said the deal is expected to use up nearly half of Acer’s current cash, in exchange for only limited earnings contribution. “We believe Acer has underestimated the risk it may encounter after the acquisition, due to the fast-dropping market share of Gateway and the weakening U.S. PC market,” it said in a statement. After trading as high…